<?php

namespace EventPortal\Http\Middleware\Event;

use Closure;
use EventPortal\Contracts\Event;
use EventPortal\Domain\Approval\Models\Approval;
use Illuminate\Http\Request;

class IsEventReadyForComplianceApproval
{
    private const LINE_MANAGER_APPROVED_STATUS = 'line-manager-approved';

    /**
     * @return mixed
     */
    public function handle(Request $request, Closure $next)
    {
        $currentUser = auth()->user();

        if (!$this->doesEventRequireLineManagerApproval($request->event)) {
            return $next($request);
        }

        if (!$this->hasLineManagerApprovedEvent($request->event)) {
            return redirect()->route('admin.dashboard.index');
        }

        return $next($request);
    }

    private function doesEventRequireLineManagerApproval(Event $event): bool
    {
        return $event->manager_id !== null;
    }

    private function hasLineManagerApprovedEvent(Event $event): bool
    {
        $approval = $event->approval()->first();

        if (!$approval instanceof Approval) {
            return false;
        }

        return $approval->status === self::LINE_MANAGER_APPROVED_STATUS;
    }
}
