<?php

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\ButtonDropdown;
use EventPortal\Domain\Component\Column\DateColumn;
use EventPortal\Domain\Component\Column\TextColumn;
use EventPortal\Domain\Component\Filter\StatusFilter;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Enums\InertiaMethod;
use EventPortal\Domain\Util\Status;

Table::make('compliance-event.index')
    ->setFilters(function () {
        return [
            StatusFilter::make('Filter by event approval status')
                ->forColumn('status')
                ->options(Status::make('eventApproval')->forFilters()),
        ];
    })
    ->setColumns(function () {
        return [
            TextColumn::make('Event name')->name('name')->searchable()->default()->sortable(),
            DateColumn::make('Date of event')
                ->name('date')
                ->value(function (Event $event) {
                    return $event->readable_dates;
                })
                ->calculated()
                ->default(),
            TextColumn::make('Event Type')->name('type')->sortable(),
            TextColumn::make('Event status')->name('status')->value(function (Event $event) {
                return optional($event->approval)->getStatusTitleAttribute() ?? '';
            })->default()->sortable()
        ];
    })
    ->setRowAction(function (Event $event) {
        return ButtonDropdown::make('Review event')
            ->actions([
                Button::make('Approve')
                    ->method(InertiaMethod::VISIT())
                    ->route('admin.event.approval.manager.approve', ['event' => $event->id]),
                Button::make('Decline')
                    ->method(InertiaMethod::VISIT())
                    ->route('admin.event.approval.manager.decline', ['event' => $event->id]),
            ]);
    });
